@@ -34,6 +34,9 @@ OC.L10N.register(
     "Create" : "ایجاد کردن",
     "Rename" : "تغییرنام",
     "Menu" : "منو",
+    "Newest first" : "تازه ترین ها اول ",
+    "Oldest first" : "قدیمی ترین ها اول ",
+    "Delete" : "حذف",
     "Dismiss" : "پنهان کن",
     "Collapse" : "فروکش  کردن",
     "Deleted folder" : "پوشه‌ی حذف شده",
