@@ -10,10 +10,12 @@ OC.L10N.register(
     "Folder" : "Պանակ",
     "New folder" : "Նոր պանակ",
     "Folder name" : "Պանակի անուն",
+    "Credentials" : "Credentials",
     "Username" : "Օգտանուն",
     "Password" : "Գաղտնաբառ",
     "Create" : "Ստեղծել",
     "Rename" : "Վերանվանել",
+    "Delete" : "հեռացնել",
     "Settings" : "Կարգավորումներ",
     "Import" : "Ներմուծում",
     "Export" : "Արտահանում",
