@@ -83,6 +83,9 @@ OC.L10N.register(
     "Undo delete feed" : "Batalkan hapus feed",
     "Rename" : "Ubah nama",
     "Menu" : "Menu",
+    "Newest first" : "Terbaru",
+    "Oldest first" : "Paling lama",
+    "Delete" : "Hapus",
     "Dismiss" : "Buang",
     "Collapse" : "Tutup",
     "Deleted folder" : "Folder yang dihapus",
