@@ -47,6 +47,9 @@ OC.L10N.register(
     "Update failed more than 50 times" : "Atjaunināšana neizdevās vairāk nekā 50 reizes",
     "Rename" : "Pārsaukt",
     "Menu" : "Izvēlne",
+    "Newest first" : "Jaunākie pirms",
+    "Oldest first" : "Vecākie pirms",
+    "Delete" : "Dzēst",
     "Dismiss" : "Atmest",
     "Collapse" : "Sakļaut",
     "Deleted folder" : "Dzēstās mapes",
