@@ -1,6 +1,8 @@
 OC.L10N.register(
     "news",
     {
+    "News" : "Nyhende",
+    "Saved" : "Lagra",
     "Download" : "Last ned",
     "Close" : "Lukk",
     "Language" : "Språk",
@@ -12,11 +14,15 @@ OC.L10N.register(
     "Folder" : "Mappe",
     "New folder" : "Ny mappe",
     "Folder name" : "Mappenamn",
+    "Credentials" : "Credentials",
     "Username" : "Brukarnamn",
     "Password" : "Passord",
     "New Folder" : "Ny mappe",
     "Create" : "Lag",
     "Rename" : "Endra namn",
+    "Newest first" : "Nyaste fyrst",
+    "Oldest first" : "Eldste fyrst",
+    "Delete" : "Ta bort",
     "Dismiss" : "Forkast",
     "Settings" : "Innstillingar",
     "Import" : "Importer",
