@@ -4,8 +4,12 @@ OC.L10N.register(
     "Download" : "ڈاؤن لوڈ،",
     "Close" : "بند ",
     "Description" : "تصریح",
+    "Folder" : "Folder",
+    "Credentials" : "Credentials",
     "Username" : "اسم صارف",
     "Password" : "پاسورڈ",
+    "Rename" : "Rename",
+    "Delete" : "حذف کریں",
     "Settings" : "سیٹینگز",
     "Help" : "مدد"
 },
