@@ -12,10 +12,14 @@ OC.L10N.register(
     "Folder" : "資料夾",
     "New folder" : "新文件夾",
     "Folder name" : "資料夾名稱",
+    "Credentials" : "Credentials",
     "Username" : "用戶名稱",
     "Password" : "密碼",
     "Create" : "新增",
     "Rename" : "重新命名",
+    "Newest first" : "最新",
+    "Oldest first" : "最舊",
+    "Delete" : "刪除",
     "Settings" : "設定",
     "Import" : "導入",
     "Export" : "輸出",
